@@ -39,7 +39,7 @@ class Store:
         self._private_keys = {}
         self._public_keys = {}
 
-        self.storage_key = storage_key
+        self.storage_key = storage_key or None
 
         self._load_keys()
 
@@ -108,7 +108,7 @@ class Store:
 
         return self._private_keys[kid]
 
-    def generate_key(self, key_size = KEY_SIZE) -> str:
+    def generate_key(self, key_size=KEY_SIZE) -> str:
         private_key = rsa.generate_private_key(
             public_exponent=Store.PUBLIC_EXPONENT,
             key_size=key_size,
